#
# Find libyui and sets the following variables
# LIBYUI_INCLUDE_DIR
# LIBYUI_LIBRARY
# UI_PLUGIN_DIR
#

# set /usr as default prefix if not set
IF ( DEFINED CMAKE_INSTALL_PREFIX )
  MESSAGE(STATUS "prefix set to ${CMAKE_INSTALL_PREFIX}")
ELSE ( DEFINED CMAKE_INSTALL_PREFIX )
  SET(CMAKE_INSTALL_PREFIX /usr)
  MESSAGE(STATUS "No prefix, set to default /usr")
ENDIF ( DEFINED CMAKE_INSTALL_PREFIX )

# Library
IF ( DEFINED LIB )
  SET ( LIB_INSTALL_DIR "${CMAKE_INSTALL_PREFIX}/${LIB}" )
ELSE ( DEFINED  LIB )
  IF (CMAKE_SIZEOF_VOID_P MATCHES "8")
    SET( LIB_SUFFIX "64" )
  ENDIF(CMAKE_SIZEOF_VOID_P MATCHES "8")
  SET ( LIB_INSTALL_DIR "${CMAKE_INSTALL_PREFIX}/lib${LIB_SUFFIX}" )
ENDIF ( DEFINED  LIB )
MESSAGE(STATUS "Libraries will be installed in ${LIB_INSTALL_DIR}" )

SET(UI_PLUGIN_DIR ${LIB_INSTALL_DIR}/YaST2/plugin)

FIND_PATH(LIBYUI_INCLUDE_DIR YWidget.h
  ${CMAKE_INSTALL_PREFIX}/include/YaST2/yui
  /usr/include/YaST2/yui
  /usr/local/include/YaST2/yui
)

FIND_LIBRARY(LIBYUI_LIBRARY NAMES yui
  PATHS
  ${LIB_INSTALL_DIR}
  /usr/local/lib
)

if(LIBYUI_INCLUDE_DIR AND LIBYUI_LIBRARY AND UI_PLUGIN_DIR)
   MESSAGE( STATUS "libyui found: includes in ${LIBYUI_INCLUDE_DIR}, library in ${LIBYUI_LIBRARY}")
   MESSAGE( STATUS "             UI plugins in ${UI_PLUGIN_DIR}")
   set(YAST_FOUND TRUE)
else(LIBYUI_INCLUDE_DIR AND LIBYUI_LIBRARY AND UI_PLUGIN_DIR)
   MESSAGE( STATUS "libyui not found")
endif(LIBYUI_INCLUDE_DIR AND LIBYUI_LIBRARY AND UI_PLUGIN_DIR)

MARK_AS_ADVANCED(LIBYUI_INCLUDE_DIR AND LIBYUI_LIBRARY AND UI_PLUGIN_DIR)

